pub struct StreamEventsResponse {
pub events_received: i64,
}Expand description
StreamEventsResponse is returned after the client closes the stream.
Fields
events_received: i64Total number of events received by the server during the stream.